API docs for “spamfighter.core.commands.partner.DomainedCommand”

# Class s.c.c.p.DomainedCommand(PartneredCommand):

Part of spamfighter.core.commands.partner View Source View In Hierarchy

Known subclasses: spamfighter.core.commands.test.test_partner.FakeDomainedCommand

Команда, которая в качестве параметра может содержать путь к поддомену, относительно которого она будет выполняться. Поддомен вычисляется относительно корневого домена партнера.

Instance Variables | domain | домен, относительно которого выполняется комананда (type: `spamfighter.interfaces.IDomain` )
| startTime | время начала обработки команды (type: `float` )

Method | init | Дополнительный метод, может переопределяться в потомках для выполнения процедуры
Method | finalize | Дополнительный метод, может переопределяться в потомках для выполнения завершения

Inherited from Command (via PartneredCommand):

Method | __init__ | Конструктор команды
Method | getResponse | Сформировать результат команды как хэш, готовый к XML-RPC преобразованию.
Method | getParams | Сформировать параметры команды как хэш, готовый к XML-RPC преобразованию.
Method | checkParams | Проверить наличие всех необходимых параметров команды.
Method | checkResult | Проверить наличие всех необходимых полей в результате выполнения команды.
Method | run | Выполнить команду.
Class | _ParamsWrapper | Класс-обертка для проверки корректности

def init(self): (source)
overrides spamfighter.core.commands.partner.PartneredCommand.init
Дополнительный метод, может переопределяться в потомках для выполнения процедуры дополнительной предварительной инициализации.

Находим домен по пути из корневого.

def finalize(self): (source)
overrides spamfighter.core.commands.command.Command.finalize
Дополнительный метод, может переопределяться в потомках для выполнения завершения обработки команды.

Обновляем счетчики.